@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2013 by Claude Bulin
+ * copyright : (C) 2003 - 2015 by Claude Bulin
  *
  * xcfa - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
@@ -45,6 +45,7 @@
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
+
 #include <string.h>
 #include <unistd.h>
 #include <dirent.h>
@@ -123,7 +124,7 @@ gchar *libutils_create_temporary_rep( gchar *SrcTmp, gchar *NewRepTmp )
 {
 	gchar	*Path = NULL;
 	gint	NumPath = 0;
-	
+
 	/*
 	if (NewRepTmp != NULL) {
 		Path = g_strdup_printf ("%s/%s", SrcTmp, NewRepTmp);
@@ -135,7 +136,7 @@ gchar *libutils_create_temporary_rep( gchar *SrcTmp, gchar *NewRepTmp )
 	}
 	return ((gchar *)Path);
 	*/
-	// FIXED 
+	// FIXED
 	// Mon, 20 Jan 2014 16:33:36 +0100
 	// Plusieurs instances de XCFA peuvent être activées sans collision pour les conversions et extractions
 	//
@@ -153,7 +154,7 @@ gchar *libutils_create_temporary_rep( gchar *SrcTmp, gchar *NewRepTmp )
 		}
 		NumPath ++;
 	}
-	
+
 	return( (gchar *)Path );
 }
 // SUPPRESSION D UN DOSSIER TEMPORAIRE
@@ -383,6 +384,7 @@ void libutils_add_datas_on_disk (gchar *data)
 }
 gchar *libutils_get_datas_on_disk (void)
 {
+	/*
 	FILE   *fp = NULL;
 	gchar  *buf = NULL;
 	size_t  size;
@@ -399,6 +401,24 @@ gchar *libutils_get_datas_on_disk (void)
 
 	g_unlink ("/tmp/data_xcfa.txt");
 
+	return ((gchar  *)buf);
+	*/
+	FILE   *fp = NULL;
+	gchar  *buf = NULL;
+	size_t  size;
+
+	if( (size = libutils_get_size_file( "/tmp/data_xcfa.txt" )) > 10 ) {
+		buf = (gchar *)g_malloc0 (sizeof(gchar) * (size + 10));
+		if ((fp = fopen ("/tmp/data_xcfa.txt", "r")) != NULL) {
+			size = fread (buf, 1, size, fp);
+			fclose (fp);
+		} else {
+			g_free (buf);
+			buf = NULL;
+		}
+	}
+	g_unlink ("/tmp/data_xcfa.txt");
+
 	return ((gchar  *)buf);
 }
 // TRUE SI ECRITURE OK SINON FALSE
