@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2013 by Claude Bulin
+ * copyright : (C) 2003 - 2015 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -35,6 +35,8 @@
 #ifndef libH_h
 #define libH_h 1
 
+
+
 // /usr/include/gtk-2.0/gdk/gdkkeysyms.h
 typedef struct {
 	gboolean	BoolVerboseMode;
@@ -100,8 +102,6 @@ gchar		*libutils_string_toupper( gchar *p_str );
 
 // COMBO.C
 // 
-void		libcombo_remove (void);
-void		libcombo_alloc (GtkComboBox *p_combo);
 void		libcombo_remove_options (GtkComboBox *p_combo);
 
 // UTF8.C
