@@ -1,9 +1,9 @@
  /*
- *  file      : bacon.h
+ *  file      : bacon.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  Code from : bacon-message-connection.h
  *              Copyright (C) 2003
@@ -47,14 +47,6 @@
 #include <sys/un.h>
 #include <errno.h>
 
-/* For the workspace/viewport stuff */
-#ifdef GDK_WINDOWING_X11
-#include <gdk/gdkx.h>
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
-#include <X11/Xatom.h>
-#endif
-
 #ifdef ENABLE_STATIC_LIBRARY
 	#include "../lib/lib.h"
 #endif
@@ -437,40 +429,3 @@ gboolean bacon_message_connection_get_is_server( BaconMessageConnection *conn )
 
 	return conn->is_server;
 }
-// 
-// 
-guint bacon_utils_get_current_workspace( void )
-{
-	GdkWindow *root_win;
-	GdkDisplay *display;
-	Atom type;
-	gint format;
-	gulong nitems;
-	gulong bytes_after;
-	guint *current_desktop;
-	gint err, result;
-	guint ret = 0;
-	GdkScreen *screen = gdk_screen_get_default ();
-
-	g_return_val_if_fail (GDK_IS_SCREEN (screen), 0);
-
-	root_win = gdk_screen_get_root_window (screen);
-	display = gdk_screen_get_display (screen);
-
-	gdk_error_trap_push ();
-	result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (root_win),
-				     gdk_x11_get_xatom_by_name_for_display (display, "_NET_CURRENT_DESKTOP"),
-				     0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
-				     &bytes_after, (gpointer) &current_desktop);
-	err = gdk_error_trap_pop ();
-
-	if (err != Success || result != Success)
-		return ret;
-
-	if (type == XA_CARDINAL && format == 32 && nitems > 0)
-		ret = current_desktop[0];
-
-	XFree (current_desktop);
-	return ret;
-}
-
