@@ -1,9 +1,9 @@
  /*
  *  file      : conv.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -46,6 +46,7 @@
 #include "global.h"
 #include "file.h"
 #include "conv.h"
+#include "configuser.h"
 
 
 /*
@@ -68,6 +69,48 @@ extern int kill (pid_t pid, int sig);
 CONV conv;
 
 
+//
+// Allocate Tab Args
+//
+gchar **conv_AllocTabArgs( gint *p_tab )
+{
+//	gint	len_malloc =
+//			50 +								// nbr elements
+//			C_list_length( Detail.ListFile );	// list length
+	gint	len_malloc = 50;
+	gchar	**PtrTab = (gchar **)g_malloc0( sizeof(gchar **) * len_malloc );
+
+	*p_tab = 0;
+	//if( Detail.Nice >= 0 && Detail.Nice <= 20) {
+		PtrTab [ 0 ] = g_strdup( "nice" );
+		PtrTab [ 1 ] = g_strdup( "-n" );
+		// PtrTab [ 2 ] = g_strdup_printf( "%d", Detail.Nice );
+		PtrTab [ 2 ] = g_strdup_printf( "%d", Config.Nice );
+		*p_tab = 3;
+	//}
+	return( (gchar **)PtrTab );
+}
+
+//
+// Remove Tab Args
+//
+gchar **conv_RemoveTab( gchar **p_PtrTabArgs )
+{
+	gint	i;
+
+	for( i = 0; p_PtrTabArgs[ i ] != NULL; i ++ ) {
+		g_free( p_PtrTabArgs[ i ] );
+		p_PtrTabArgs[ i ] = NULL;
+	}
+	g_free( p_PtrTabArgs );
+	p_PtrTabArgs = NULL;
+
+	return( (gchar **)NULL );
+}
+
+
+
+
 /*
 *---------------------------------------------------------------------------
 * STOP THREAD AND TIMEOUT
