@@ -1,25 +1,25 @@
  /*
  *  file      : main.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
  *
  *  This file is part of XCFA.
- * 
+ *
  *  XCFA is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  at your option) any later version.
- * 
+ *
  *  XCFA is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -41,14 +41,6 @@
 #include <sys/types.h>
 #include <locale.h>
 
-/* For the workspace/viewport stuff */
-#ifdef GDK_WINDOWING_X11
-#include <gdk/gdkx.h>
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
-#include <X11/Xatom.h>
-#endif
-
 #ifdef ENABLE_STATIC_LIBRARY
 	#include "../lib/lib.h"
 #endif
@@ -64,7 +56,7 @@
 #include "dvd.h"
 #include "web.h"
 #include "poche.h"
-#include "treeview.h"
+#include "win_treeview.h"
 #include "get_info.h"
 #include "mplayer.h"
 #include "win_about.h"
@@ -88,51 +80,52 @@ BaconMessageConnection *connection = NULL;
 
 KEYS keys = {
 	FALSE,		// gboolean	BoolGDKPress
-	FALSE,		// gboolean	BoolGDK_Control_L_R
+	FALSE,		// gboolean	BoolGDK_KEY_Control_L_R
 	FALSE,		// gboolean	BoolGDK_Control_A
 	0,		// guint	keyval
 };
 
 
-// 
-// 
+//
+//
 void on_label_statusbar_global_realize (GtkWidget *widget, gpointer user_data)
 {
 	AdrLabelStatusbarGlobal = widget;
 }
 // -RECUPERATION DES DATAS
 // -SAUVEGARDE DES DATAS
-// 
+//
 void remove_memory_apply (void)
 {
 	static gboolean BoolDoEnterRemove = FALSE;
-	
+
 	if (TRUE == BoolDoEnterRemove) return;
 	BoolDoEnterRemove = TRUE;
-	
+
 	VERBOSE ("\n--------------------------------------------------\n");
 	PRINT_FUNC_LF();
 	VERBOSE ("--------------------------------------------------\n");
-	
+
 	VERBOSE("AlsaPlay_stop ()\n")
 	AlsaPlay_stop ();
-	
+
 	VERBOSE ("split_set_stop ()\n");
 	split_set_stop ();
-	
+
 	VERBOSE ("Recuperation position et taille de la fenetre\n");
-	gdk_window_get_root_origin (WindMain->window, &Config.WinPos_X, &Config.WinPos_Y);
-	gdk_window_get_size (WindMain->window, &Config.WinWidth, &Config.WinHeight);	
-	
+	gdk_window_get_root_origin( gtk_widget_get_window(WindMain), &Config.WinPos_X, &Config.WinPos_Y );
+	Config.WinWidth  = gdk_window_get_width( gtk_widget_get_window(WindMain) );
+	Config.WinHeight = gdk_window_get_height( gtk_widget_get_window(WindMain) ) ;
+
 	VERBOSE ("Sauvegarde l'etat de l'expander CD\n");
 	Config.BoolEtatExpanderCd = gtk_expander_get_expanded (GTK_EXPANDER (var_cd.Adr_Expander));
-	
+
 	VERBOSE ("Sauvegarde de la configuration\n");
 	config_save ();
-	
+
 	VERBOSE ("config_remove ()\n");
 	config_remove ();
-	
+
 	VERBOSE ("fileanalyze_remove_entetefile ()\n");
 	fileanalyze_remove_entetefile ();
 
@@ -146,46 +139,43 @@ void remove_memory_apply (void)
 
 	VERBOSE ("NotifySend_remove ()\n");
 	NotifySend_remove ();
-	
+
 	VERBOSE ("Parse_remove (PARSE_TYPE_STOCKAGE_CD)\n");
 	Parse_remove (PARSE_TYPE_STOCKAGE_CD, TRUE);
 	VERBOSE ("Parse_remove (PARSE_TYPE_TITLE_CD)\n");
 	Parse_remove (PARSE_TYPE_TITLE_CD, TRUE);
-	
+
 	VERBOSE ("poche_remove_view()\n");
 	poche_remove_view();
-	
+
 	VERBOSE ("poche_remove_ListImage()\n");
 	poche_remove_ListImage();
 
-	VERBOSE ("libcombo_remove ()\n");
-	libcombo_remove ();
-
 	VERBOSE ("scan_remove_glist_media ()\n");
 	scan_remove_glist_media ();
 
 	VERBOSE ("web_remove_temporary_rep ()\n");
 	web_remove_temporary_rep ();
-	
+
 	VERBOSE ("CdCurl_remove_struct_all ()\n");
 	CdCurl_remove_struct_all();
-	
+
 	VERBOSE ("mplayer_remove_list_args ()\n");
 	mplayer_remove_list_args ();
-	
+
 	VERBOSE ("SplitSpectre_remove ()\n");
 	SplitSpectre_remove ();
-	
+
 	VERBOSE ("AlsaPlay_remove ()\n");
 	AlsaPlay_remove ();
-		
+
 	if (TRUE == libutils_test_file_exist (XCFA_FILE_LOAD)) {
-		if( TRUE == OptionsCommandLine.BoolVerboseMode ) 
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
 			g_print ("g_unlink (%s)\n", XCFA_FILE_LOAD);
 		g_unlink (XCFA_FILE_LOAD);
 	}
 	if (TRUE == libutils_test_file_exist (SPLIT_FILE_TMP_WAV)) {
-		if( TRUE == OptionsCommandLine.BoolVerboseMode ) 
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
 			g_print ("g_unlink (%s)\n", SPLIT_FILE_TMP_WAV);
 		g_unlink (SPLIT_FILE_TMP_WAV);
 	}
@@ -193,7 +183,7 @@ void remove_memory_apply (void)
 	StatusBar_remove();
 
 	Config.PathPochette = libutils_remove_temporary_rep( Config.PathPochette );
-	
+
 	if( NULL != Config.PathLoadImg ) {
 		g_free( Config.PathLoadImg );
 		Config.PathLoadImg = NULL;
@@ -205,13 +195,13 @@ void remove_memory_apply (void)
 
 	g_print ("\n");
 }
-// 
-// 
-void on_notebook_general_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)
+//
+//
+void on_notebook_general_switch_page( GtkNotebook *notebook, gpointer page, guint page_num, gpointer user_data )
 {
 	if (TRUE == Config.BoolConfigOk) {
 		Config.NotebookGeneral = page_num;
-		
+
 		if (NOTEBOOK_SPLIT == Config.NotebookGeneral) {
 			split_set_name_file ();
 		}
@@ -220,38 +210,38 @@ void on_notebook_general_switch_page (GtkNotebook *notebook, GtkNotebookPage *pa
 		}
 	}
 }
-// 
-// 
-void on_notebook_expander_cd_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)
+//
+//
+void on_notebook_expander_cd_switch_page( GtkNotebook *notebook, gpointer page, guint page_num, gpointer user_data )
 {
 	if (TRUE == Config.BoolConfigOk)
 		Config.NotebookExpanderCd = page_num;
 }
-// 
-// 
-void on_notebook_in_file_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)
+//
+//
+void on_notebook_in_file_switch_page( GtkNotebook *notebook, gpointer page, guint page_num, gpointer user_data )
 {
 	if (TRUE == Config.BoolConfigOk) {
 		Config.NotebookFile = page_num;
 		switch (Config.NotebookFile) {
 		case NOTEBOOK_FICHIERS_CONVERSION :
-			gtk_combo_box_remove_text (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), 2);
-			gtk_combo_box_append_text (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), Config.PathDestinationFileAll);
+			gtk_combo_box_text_remove( GTK_COMBO_BOX_TEXT(var_file.Adr_combobox_DestFile), 2 );
+			gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_file.Adr_combobox_DestFile), Config.PathDestinationFileAll);
 			gtk_combo_box_set_active (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), Config.TabIndiceComboDestFile[ NOTEBOOK_FICHIERS_CONVERSION ]);
 			break;
 		case NOTEBOOK_FICHIERS_WAV :
-			gtk_combo_box_remove_text (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), 2);
-			gtk_combo_box_append_text (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), Config.PathDestinationFileWav);
+			gtk_combo_box_text_remove( GTK_COMBO_BOX_TEXT(var_file.Adr_combobox_DestFile), 2 );
+			gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_file.Adr_combobox_DestFile), Config.PathDestinationFileWav);
 			gtk_combo_box_set_active (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), Config.TabIndiceComboDestFile[ NOTEBOOK_FICHIERS_WAV ]);
 			break;
 		case NOTEBOOK_FICHIERS_MP3OGG :
-			gtk_combo_box_remove_text (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), 2);
-			gtk_combo_box_append_text (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), Config.PathDestinationFileMp3Ogg);
+			gtk_combo_box_text_remove( GTK_COMBO_BOX_TEXT(var_file.Adr_combobox_DestFile), 2 );
+			gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_file.Adr_combobox_DestFile), Config.PathDestinationFileMp3Ogg);
 			gtk_combo_box_set_active (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), Config.TabIndiceComboDestFile[ NOTEBOOK_FICHIERS_MP3OGG ]);
 			break;
 		case NOTEBOOK_FICHIERS_TAGS :
-			gtk_combo_box_remove_text (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), 2);
-			gtk_combo_box_append_text (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), Config.PathDestinationFileTags);
+			gtk_combo_box_text_remove( GTK_COMBO_BOX_TEXT(var_file.Adr_combobox_DestFile), 2 );
+			gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_file.Adr_combobox_DestFile), Config.PathDestinationFileTags);
 			gtk_combo_box_set_active (GTK_COMBO_BOX (var_file.Adr_combobox_DestFile), Config.TabIndiceComboDestFile[ NOTEBOOK_FICHIERS_TAGS ]);
 			break;
 		}
@@ -259,49 +249,49 @@ void on_notebook_in_file_switch_page (GtkNotebook *notebook, GtkNotebookPage *pa
 		StatusBar_puts();
 	}
 }
-// 
-// 
-void on_notebook_options_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)
+//
+//
+void on_notebook_options_switch_page( GtkNotebook *notebook, gpointer page, guint page_num, gpointer user_data )
 {
 	if (TRUE == Config.BoolConfigOk)
 		Config.NotebookOptions = page_num;
 }
-// 
-// 
-void on_notebook_app_externes_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)
+//
+//
+void on_notebook_app_externes_switch_page( GtkNotebook *notebook, gpointer page, guint page_num, gpointer user_data )
 {
 	if (TRUE == Config.BoolConfigOk)
 		Config.NotebookAppExterns = page_num;
 }
-// 
-// 
+//
+//
 gboolean on_wind_main_key_press_event( GtkWidget *widget, GdkEventKey *kevent, gpointer user_data )
 {
 	keys.BoolGDKPress = TRUE;
 	keys.keyval       = kevent->keyval;
-	
-	if( kevent->keyval == GDK_Control_L || kevent->keyval == GDK_Control_R ) {
+
+	if( kevent->keyval == GDK_KEY_Control_L || kevent->keyval == GDK_KEY_Control_R ) {
 		keys.BoolGDK_Control_L_R = TRUE;
-	}		
+	}
 	else if( kevent->state == 20 || kevent->state == 21 ) {
 		if( kevent->keyval == 65 || kevent->keyval == 97 ) {
 			keys.BoolGDK_Control_A = TRUE;
 		}
 	}
-	
+
 	if( NOTEBOOK_POCHETTE == Config.NotebookGeneral ) {
 		if( TRUE == keys.BoolGDK_Control_L_R ) {
 			pochedir_set_ctrl( TRUE );
 		}
-		else if( kevent->keyval == GDK_Delete) {
+		else if( kevent->keyval == GDK_KEY_Delete) {
 			// poche_remove_image();
 		}
 	}
 	else if( NOTEBOOK_SPLIT == Config.NotebookGeneral ) {
-		if( kevent->keyval == GDK_Delete ) {
+		if( kevent->keyval == GDK_KEY_Delete ) {
 			SplitSelector_cut ();
 		}
-		else if( kevent->keyval == GDK_space ) {
+		else if( kevent->keyval == GDK_KEY_space ) {
 			// Une action sur la barre espace agit sur sur le play/pause
 			split_play ();
 		}
@@ -309,19 +299,19 @@ gboolean on_wind_main_key_press_event( GtkWidget *widget, GdkEventKey *kevent, g
 
 	return FALSE;
 }
-// 
-// 
+//
+//
 gboolean on_wind_main_key_release_event( GtkWidget *widget, GdkEventKey *kevent, gpointer user_data )
 {
 	keys.BoolGDKPress        = FALSE;
 	keys.BoolGDK_Control_L_R = FALSE;
 	keys.BoolGDK_Control_A   = FALSE;
 	keys.keyval              = 0;
-	
+
 	if( NOTEBOOK_POCHETTE == Config.NotebookGeneral ) {
 		pochedir_set_ctrl( FALSE );
 	}
-	
+
 	return FALSE;
 }
 
@@ -340,48 +330,49 @@ gboolean on_wind_main_window_state_event( GtkWidget *widget, GdkEventWindowState
 	} GdkWindowState;
 	*/
 	if( GDK_WINDOW_STATE_MAXIMIZED == event->new_window_state ) {
-		gdk_window_maximize( WindMain->window );
+		gdk_window_maximize( gtk_widget_get_window(WindMain) );
 	}
 	return FALSE;
 }
 
-// 
-// 
+//
+//
 gboolean on_wind_main_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 	remove_memory_apply ();
 	gtk_main_quit ();
 	return FALSE;
 }
-// 
-// 
+//
+//
 gboolean on_wind_main_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 	remove_memory_apply ();
 	gtk_main_quit ();
 	return FALSE;
 }
-// 
-// 
+//
+//
 void on_quitter1_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
 	remove_memory_apply ();
 	gtk_main_quit ();
 }
-// 
-// 
+//
+//
 void on_a_propos1_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
 	gchar	*StrAboutXcfa = g_strdup_printf ("About XCFA  -  %s", VERSION);
-	WinAbout_open (StrAboutXcfa);
+	// WinAbout_open (StrAboutXcfa);
+	wind_about_init( WindMain );
 	g_free (StrAboutXcfa);
 	StrAboutXcfa = NULL;
 }
-// 
-// 
+//
+//
 void on_show_fields_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	treeview_open_window ();
+	wintreeview_init( WindMain );
 }
 /* Install un 'handler' sur une mauvaise allocation memoire
 *  --
@@ -392,37 +383,37 @@ void segfault_handler(int sig)
 {
 	g_unlink (XCFA_FILE_LOAD);
 	remove_memory_apply ();
-	
+
 	g_print ("\n=========================================================\n");
 	g_print ("=  Segmentation fault\n");
-	g_print (_("=  Adressage memoire invalide\n"));
+	g_print ("=  Adressage memoire invalide\n");
 	g_print ("=-------------------------------------------------------=\n");
 	g_print ("=      You've probably found a bug in XCFA\n");
-	g_print (_("=      Vous avez probablement trouve un bug dans XCFA\n"));
+	g_print ("=      Vous avez probablement trouve un bug dans XCFA\n");
 	g_print ("=========================================================\n\n");
-		
+
 	exit (EXIT_FAILURE);
 }
-// 
-// 
+//
+//
 typedef enum {
 	_PARAMS_GET_ALL_OPTIONS_ = 0,
 	_PARAMS_GET_OPTIONS_ONLY_
 } PARAMS_CMD_LINE;
-// 
-// 
+//
+//
 GList *AnalyseCommandLine_set_argv( gint argc, gchar *argv[], PARAMS_CMD_LINE ParamsCmdLine )
 {
 	gint	 i;
 	gchar	*str_current_dir = NULL;
 	// FILE	*fp = NULL;
 	GList	*GListFile = NULL;
-		
+
 	if( optind < argc ) {
-		
+
 		for( i = optind; i < argc; i++ ) {
 			// VERBOSE MODE
-			if( 0 == strcmp( argv[i], "-verbose" )) {
+			if( 0 == strcmp( argv[i], "--verbose" )) {
 				OptionsCommandLine.BoolVerboseMode = TRUE;
 				// g_print( "\nVERBOSE MODE:\n");
 				// g_print( "	argv[ %d ] = %s\n", i, argv[ i ] );
@@ -430,7 +421,7 @@ GList *AnalyseCommandLine_set_argv( gint argc, gchar *argv[], PARAMS_CMD_LINE Pa
 				// g_print( "\n" );
 			}
 			// VERSION MODE
-			else if( 0 == strcmp( argv[i], "-version" )) {
+			else if( 0 == strcmp( argv[i], "--version" )) {
 				OptionsCommandLine.BoolVersionMode = TRUE;
 				// g_print( "\nVERSION MODE:\n");
 				// g_print( "	argv[ %d ] = %s\n", i, argv[ i ] );
@@ -438,21 +429,21 @@ GList *AnalyseCommandLine_set_argv( gint argc, gchar *argv[], PARAMS_CMD_LINE Pa
 				// g_print( "\n" );
 			}
 			// HELP MODE
-			else if( 0 == strcmp( argv[i], "-help" ) || 0 == strcmp( argv[i], "-h" )) {
+			else if( 0 == strcmp( argv[i], "--help" ) || 0 == strcmp( argv[i], "-h" )) {
 				OptionsCommandLine.BoolHelpMode = TRUE;
 			}
 		}
-		
+
 		// STOP ?
 		if( _PARAMS_GET_OPTIONS_ONLY_ == ParamsCmdLine )return( (GList *)NULL );
-		
+
 		if( FALSE == OptionsCommandLine.BoolVerboseMode && FALSE == OptionsCommandLine.BoolVersionMode ) {
 			str_current_dir = g_get_current_dir();
 			// fp = fopen( XCFA_FILE_LOAD, "a" );
 			for( i = optind; i < argc; i++ )
-			{				
+			{
 				if( *argv[ i ] == '-' ) continue;
-				
+
 				// FROM DESKTOP
 				if( argv[i][0] == '/' ) {
 
@@ -461,7 +452,7 @@ GList *AnalyseCommandLine_set_argv( gint argc, gchar *argv[], PARAMS_CMD_LINE Pa
 				}
 				else {
 					gchar *str = NULL;
-				
+
 					str = g_strdup_printf( "%s/%s", str_current_dir, argv[i] );
 					// fprintf( fp, "%s\n", str );
 					GListFile = g_list_append( GListFile, g_strdup( str ));
@@ -476,14 +467,14 @@ GList *AnalyseCommandLine_set_argv( gint argc, gchar *argv[], PARAMS_CMD_LINE Pa
 	}
 	return( (GList *)GListFile );
 }
-// 
-// 
+//
+//
 void main_save( GList *p_GListFile )
 {
 	GList   *list = NULL;
 	gchar	*PtrName = NULL;
 	FILE	*fp = NULL;
-	
+
 	// g_return_if_fail (p_GListFile != NULL);
 	if( NULL != p_GListFile ) {
 		if( NULL != (list = g_list_first( p_GListFile ))) {
@@ -499,12 +490,12 @@ void main_save( GList *p_GListFile )
 		}
 	}
 }
-// 
-// 
+//
+//
 static void on_message_received( const char *message, gpointer data )
 {
 	FILE	*fp = NULL;
-	
+
 	fp = fopen( XCFA_FILE_LOAD, "a" );
 	fprintf( fp, "%s\n", message );
 	fclose( fp );
@@ -529,7 +520,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	/* Init type system as soon as possible */
 	// g_type_init ();
 	g_set_prgname ("xcfa");
-	
+
 	PRINT_FUNC_LF();
 	g_print ("\n");
 	g_print ("***************************\n");
@@ -541,16 +532,16 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	g_print ("Gtk version  = %d.%d.%d\n", GTK_MAJOR_VERSION, GTK_MICRO_VERSION, GTK_MINOR_VERSION);
 	g_print ("Glib version = %d.%d.%d\n", GLIB_MAJOR_VERSION, GLIB_MICRO_VERSION, GLIB_MINOR_VERSION);
 	g_print ("***************************\n\n");
-	
+
 	// ANALYSE UNIQUEMENT LES OPTIONS
 	AnalyseCommandLine_set_argv( argc, &argv[0], _PARAMS_GET_OPTIONS_ONLY_ );
-	
+
 	if( TRUE == OptionsCommandLine.BoolVersionMode || TRUE == OptionsCommandLine.BoolHelpMode ) {
 		if( TRUE == OptionsCommandLine.BoolHelpMode ) {
 			g_print( "HELP MODE:\n");
-			g_print( "	-help -h	Displays this help section and exits\n" );
-			g_print( "	-version	Displays the version of the program and exits\n" );
-			g_print( "	-verbose	Activate verbose mode\n" );
+			g_print( "	--help -h	Displays this help section and exits\n" );
+			g_print( "	--version	Displays the version of the program and exits\n" );
+			g_print( "	--verbose	Activate verbose mode\n" );
 		}
 		g_print( "\n" );
 		g_unlink( XCFA_FILE_LOAD );
@@ -562,9 +553,9 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
 		g_print ("ENABLE_NLS OK\n");
 		g_print ("\tGETTEXT_PACKAGE    = %s\n", GETTEXT_PACKAGE);
-		g_print ("\tLOCALE_DIR         = %s\n", LOCALE_DIR);	
+		g_print ("\tLOCALE_DIR         = %s\n", LOCALE_DIR);
 	}
-		
+
 	setlocale( LC_ALL, "" );
 	bindtextdomain (GETTEXT_PACKAGE, LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -572,14 +563,14 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 #else
 	// g_error ("ENABLE_NLS IS NOT OK\n\n");
 #endif
-	
+
 	GetInfo_cpu_print ();
-	
-	// IF Segmentation fault 
+
+	// IF Segmentation fault
 	signal (SIGSEGV, segfault_handler);
-	
+
 	config_read();
-	
+
 	setlocale( LC_ALL, "" );
 	gtk_init( &argc, &argv );
 
@@ -595,7 +586,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	connection = bacon_message_connection_new( "xcfa" );
 	if( NULL != connection )
 	{
-		if( FALSE == bacon_message_connection_get_is_server( connection )) 
+		if( FALSE == bacon_message_connection_get_is_server( connection ))
 		{
 			// g_print( "\nCLIENT:\nGET COMMAND LINE AND EXIT\n" );
 			GListFile = AnalyseCommandLine_set_argv( argc, &argv[0], _PARAMS_GET_ALL_OPTIONS_ );		// Get and save param-file
@@ -605,10 +596,10 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 			GListFile = libutils_remove_glist( GListFile );
 			// g_print( "bacon_utils_get_current_workspace() = %d\n",  bacon_utils_get_current_workspace() +1 );
 			bacon_message_connection_free( connection );
-			
+
 			exit( EXIT_SUCCESS );
 		}
-		else 
+		else
 		{
 			g_unlink( XCFA_FILE_LOAD );
 			g_unlink( SPLIT_FILE_TMP_WAV );
@@ -625,10 +616,8 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	{
 		g_warning( "Cannot create the 'gedit' connection." );
 	}
-	
-	gdk_threads_enter ();
+
 	if (NULL == (GtkXcfaProjet = gtk_builder_new ())) {
-		gdk_threads_leave ();
 		return (EXIT_FAILURE);
 	}
 	gtk_builder_set_translation_domain (GtkXcfaProjet, NULL);
@@ -647,14 +636,13 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 		g_print("! File XML: [ %s ] %s\n", PathShareProjet != NULL ? PathShareProjet : PACKAGE_NAME_GLADE, g_file_test (PathShareProjet, G_FILE_TEST_EXISTS) ? "Found" : "Not Found !!!" );
 		g_print("!---\n");
 	}
-	
+
 	if (FALSE == g_file_test (PathCurrentDir, G_FILE_TEST_EXISTS) && FALSE == g_file_test (PathShareProjet, G_FILE_TEST_EXISTS)) {
 		g_free (PathCurrentDir);
 		PathCurrentDir = NULL;
 		g_free (PathShareProjet);
 		PathShareProjet = NULL;
 
-		gdk_threads_leave ();
 		return (EXIT_FAILURE);
 	}
 	else if (TRUE == g_file_test (PathCurrentDir, G_FILE_TEST_EXISTS)) {
@@ -677,7 +665,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 		PathShareProjet = NULL;
 		Path = NULL;
 
-		gdk_threads_leave ();
 		return (EXIT_FAILURE);
 	}
 	g_free (PathCurrentDir);
@@ -689,26 +676,26 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	gtk_builder_set_translation_domain  (GtkXcfaProjet, setlocale( LC_ALL, "" ) );
 	gtk_builder_connect_signals (GtkXcfaProjet, NULL);
 	WindMain = GTK_WIDGET (GLADE_GET_OBJECT("wind_main"));
-	
+
 	// REDIMENSIONNER LA FENETRE
 	gtk_window_resize(GTK_WINDOW(WindMain), Config.WinWidth, Config.WinHeight);
 	// PLACER LA FENETRE
 	gtk_window_move(GTK_WINDOW(WindMain), Config.WinPos_X, Config.WinPos_Y);
-	
+
 	PackageVersion = g_strdup_printf ("X Convert File Audio  -  %s", VERSION);
 	gtk_window_set_title (GTK_WINDOW (WindMain), PackageVersion);
 	g_free (PackageVersion);
 	PackageVersion = NULL;
-	
+
 	libutils_set_default_icone_to_win (WindMain);
-		
+
 	gtk_widget_show (WindMain);
-	
+
 	// NOTEBOOK
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), NOTEBOOK_PRGEXTERNES);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_app_externes")), NOTEBOOK_OPTIONS_EXTRA);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_app_externes")), NOTEBOOK_OPTIONS_PRGEXTERNES);
-		
+
 	// OPTIONS
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), NOTEBOOK_OPTIONS);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_options")), NOTEBOOK_OPTIONS_EXPORT_TAGS);
@@ -744,13 +731,13 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 
 	// DVD-AUDIO
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), NOTEBOOK_DVD_AUDIO);
-	
+
 	var_options.ColorLineCommand = COLOR_INIT;
 	options_set_all_interne ();
 	var_options.ColorLineCommand = COLOR_NONE;
-	
+
 	Config.BoolConfigOk = TRUE;
-	
+
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), Config.NotebookGeneral);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_expander_cd")), Config.NotebookExpanderCd);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_in_file")), Config.NotebookFile);
@@ -759,7 +746,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	if (NOTEBOOK_SPLIT == Config.NotebookGeneral) {
 		split_set_name_file ();
 	}
-	
+
 	cdaudio_set_flag_buttons ();
 	file_set_flag_buttons ();
 	FileWav_set_flag_buttons ();
@@ -767,39 +754,39 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	FileTags_set_flag_buttons ();
 	gtk_widget_set_sensitive (GTK_WIDGET (var_file_tags.Adr_table_tag), FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_tag_appliquer")), FALSE);
-	
+
 	gtk_widget_hide( GTK_WIDGET (GLADE_GET_OBJECT("frame_discid")));
 	
-	treeview_set_etat_fields ();
-	treeview_radiobutton_set_PosFieldsName ();
-	
-	filetrash_test_trash_is_ok ();
+	// TODO: re-encoding unit [ poche_web.c ] function [ void pocheweb_analyze_file_html( void ) ] -> OK
+	// gtk_widget_hide( GTK_WIDGET (GLADE_GET_OBJECT("frame_import_img_web")));
+
+	wintreeview_set_etat_fields ();
+	wintreeview_radiobutton_set_PosFieldsName ();
+
 	poche_set_flag_buttons();
-	
+
 	// SI CHARGEMENT DE FICHIERS DEPUIS LE BUREAU AVEC LE MENU CONTEXTUEL
 	process_goto_timeout ();
-	
+
 	// ADMINISTRATOR MODE ?
 	if( 0 == getuid() ) {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("MODE ADMINISTRATEUR"),
+			_("ADMINISTRATOR MODE"),
 			  "\n",
-			_("   Vous ne devriez pas utiliser   "),
+			_("   You should not use   "),
 			  "\n",
-			_("   XCFA sous ROOT !"),
+			_("  XCFA under ROOT    !"),
 			  "\n",
 			"");
 	}
 
 	xdg_print_list_config_path();
 	xdg_print_list_data_path();
-	
+
 	gtk_main ();
 
 	// bacon_message_connection_free( connection );
-	
-	gdk_threads_leave ();
 
 	exit(EXIT_SUCCESS);
 }
