@@ -1,9 +1,9 @@
  /*
  *  file      : poche_web.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -145,10 +145,10 @@ void pocheweb_analyze_file_html (void)
 	gchar	*buffer = NULL;
 	gchar   *result = NULL;
 	FILE    *fp;
-	gchar   *PtrBegin = NULL;
-	gchar   *PtrEnd = NULL;
 	gchar   *PtrName = NULL;
-	gint	NumFile = 1;
+	const	char *prefix = "/images?q=tbn:";
+	char	*url_start = NULL;
+	char	*url_end = NULL;
 	
 	PRINT_FUNC_LF();
 
@@ -168,71 +168,48 @@ void pocheweb_analyze_file_html (void)
 	fread (buffer, 1, lenfile, fp);
 	fclose (fp);
 
-	// 
-	// RECHERCHE D'UNE SEQUENCE:
-	//	.jpg
-	// ... PRECEDEE D'UNE SEQUENCE:
-	//	http://
-	// 
-	PtrEnd = buffer;
-	// BOUCLE
-	while( (PtrEnd - buffer) < lenfile ) {
-		// SEARCH END STRING '.jpg'
-		if( NULL != ( PtrEnd = strstr( PtrEnd, ".jpg" ))) {
-			PtrBegin = PtrEnd;
-			PtrBegin --;
-			PtrEnd += 4;
-			// SEARCH BEGIN STRING 'http:'
-			while( PtrBegin > buffer ) {
+	url_start = buffer;
+	do {
+		url_start = strstr( url_start, prefix );
+		if( NULL != url_start ) {
+			url_end = strstr( url_start, "\"" );
+			if( NULL != url_end ) {
 				
-				if( *(PtrBegin + 0) == 'h' &&
-				    *(PtrBegin + 1) == 't' &&
-				    *(PtrBegin + 2) == 't' &&
-				    *(PtrBegin + 3) == 'p' &&
-				    *(PtrBegin + 4) == ':' ) {
-					
-					// MAKE STRING
-					result = g_strnfill( (PtrEnd - PtrBegin) + 10, '\0' );
-					// GET STRING
-					strncpy( result, PtrBegin, PtrEnd - PtrBegin );
+				result = g_strnfill( (url_end - url_start) + 100, '\0' );
+				strcpy( result, "www.google.com/" );
+				strncat( result, url_start, url_end - url_start );
+				
+				// printf("result = www.google.com/%s\n", result );
+				
+				if ((PtrName = pocheweb_get_on_web_file_img (result))) {
+					if (pocheweb_event.name) {
+						g_free (pocheweb_event.name);
+						pocheweb_event.name = NULL;
+					}
+					pocheweb_event.name = g_strdup( PtrName );
+					pochedir_make_glist( PtrName );
 					
+					g_free( PtrName );
+					PtrName = NULL;
+				}
+				
+				url_start = url_end + 1;
+				
+				g_free( result );
+				result = NULL;
+				
+				if (WindScan_close_request ()) {
 					if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
-						g_print( "NumFile = %d\n", NumFile );
-						g_print( "result = %s\n", result );
+						g_print ("DEMANDE D'ANNULATION DEPUIS: ");
+						PRINT_FUNC_LF();
 					}
-					NumFile ++;
-					
-					if ((PtrName = pocheweb_get_on_web_file_img (result))) {
-						if (pocheweb_event.name) {
-							g_free (pocheweb_event.name);
-							pocheweb_event.name = NULL;
-						}
-						pocheweb_event.name = g_strdup( PtrName );
-						pochedir_make_glist( PtrName );
-						
-						g_free( PtrName );
-						PtrName = NULL;
-					}
-					g_free( result );
-					result = NULL;
 					break;
 				}
-				else {
-					PtrBegin --;
-				}
-			}
-			
-			if (WindScan_close_request ()) {
-				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
-					g_print ("DEMANDE D'ANNULATION DEPUIS: ");
-					PRINT_FUNC_LF();
-				}
-				break;
+				
 			}
+			else break;
 		}
-		PtrEnd ++;
-		if ((PtrEnd - buffer) >= lenfile -100) break;
-	}
+	} while( NULL != url_start );
 
 	g_free (buffer);
 	buffer = NULL;
@@ -342,20 +319,20 @@ static gint pocheweb_timeout (gpointer data)
 		pochedir_table_add_images ();
 		// pocheevnt_set_flag_buttons_recto ();
 		// pocheevnt_set_flag_buttons_verso ();
-		gtk_timeout_remove (pocheweb_event.timeout);
+		g_source_remove (pocheweb_event.timeout);
 		
 		WindScan_close ();
 
 		if (pocheweb_bool_file_add () == FALSE) {
-			wininfo_create (
+			wind_info_init (
 				WindMain,
-				_("Aucun fichier trouve !"),
-				_("Pour resoudre ce probleme:"),
+				_("No file found !"),
+				_("To solve this problem :"),
 				  "\n",
 				  "-----------------------------------\n",
-				_("Modifiez la chaine de recherche et"),
+				_("Modify the search parameters and"),
 				  "\n",
-				_("recommencez."),
+				_("start again."),
 			  	  "");
 		}
 	}
@@ -369,33 +346,31 @@ void pocheweb_get (void)
 	// PRINT_FUNC_LF();
 	
 	if( NULL == StrEntryWeb || '\0' == *StrEntryWeb ) {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("Critere de recherche absent  !!"),
-			_("Pour resoudre ce probleme:"),
+			_("Search criteria away  !!"),
+			_("To solve this problem :"),
 			  "\n",
 			  "-----------------------------------\n",
-			_("Saisissez une chaine de recherche et"),
-			  "\n",
-			_("recommencez."),
+				_("Modify the search parameters and"),
+				  "\n",
+				_("start again."),
 		  	  "");
 		return;
 	}
 	pocheweb_event.pocheweb_tt_glist = g_list_length (view.glist);
-	WindScan_open ("Recherche des fichiers images", WINDSCAN_PULSE);
+	// WindScan_open ("Recherche des fichiers images", WINDSCAN_PULSE);
+	wind_scan_init(
+		WindMain,
+		"Recherche des fichiers images",
+		WINDSCAN_PULSE
+		);
 	WindScan_set_label ("<b><i>Recherche des fichiers images ...</i></b>");
-	pocheweb_event.name = g_strdup (_("[Recherche des fichiers images]"));
+	pocheweb_event.name = g_strdup (_("[Search images files]"));
 	pocheweb_event.name = NULL;
 	pocheweb_event.EndThread = FALSE;
 	pocheweb_event.EndTimeout = FALSE;
-	pocheweb_event.timeout = gtk_timeout_add (10, pocheweb_timeout, 0);
+	pocheweb_event.timeout = g_timeout_add (10, pocheweb_timeout, 0);
 	pthread_create (&pocheweb_event.nmr_tid, NULL ,(void *)pocheweb_thread, (void *)NULL);
 }
 
-
-
-
-
-
-
-
