@@ -1,9 +1,9 @@
  /*
  *  file      : scan_cd.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -254,18 +254,18 @@ GList *scan_scan_drives_cd_dvd (void)
 	
 	/* test is 'dvd+rw-tools package' present ? */
 	if (libutils_find_file ("dvd+rw-mediainfo") == FALSE) {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("PACKAGE dvd+rw-tools ABSENT"),
-			_("Le package 'dvd+rw-tools' est absent"),
+			_("PACKAGE dvd+rw-tools is missing"),
+			_("The package 'imagemagick' is missing"),
 			  "\n",
-			_("de votre systeme !"),
+			_("on your system !"),
 			  "\n\n",
-			_("Veuillez l'installer car j'ai besoin de"),
+			_("Please install it and resume"),
 			  "\n",
-			_("'dvd+rw-mediainfo' pour identifier le(s)"),
+			_("'Dvd + rw-mediainfo' to identify the"),
 			  "\n",
-			_("lecteur(s) de cd / dvd."),
+			_("reader of cd / dvd."),
 			  "");
 			return (NULL);
 	}
