@@ -1,9 +1,9 @@
  /*
  *  file      : split.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -62,9 +62,9 @@
 
 
 
-extern gint		 n_drag_types;			/* Drag And Drop	*/
-VAR_SPLIT VarSplit;
-ADJUST Adjust;
+extern gint		 n_drag_types;			// Drag And Drop
+VAR_SPLIT	VarSplit;
+ADJUST		Adjust;
 
 void SetAjust (void);
 
@@ -199,21 +199,19 @@ void SplitSpectre_scroll_droite_play (void)
 	gdouble			Value;
 	gint			Begin;
 	gint			LenScroll;
+	GtkAllocation	allocation;
 	
 	if (VarSplit.NbrSelecteurs == 0) return;
-	
 	SplitSelector_get_pos ();
-	
-	Value = (gint)VarSplit.AdjScroll->value;
-	
-	LenScroll = VARSPLIT_SPECTRE_WITH -1;
+	Value = gtk_adjustment_get_value( VarSplit.AdjScroll );
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
+	LenScroll = allocation.width -1;
 	Begin     = SplitSelector_get_pos_play ()  - (gint)Value;
 		
 	while( Begin > 100 && Value + LenScroll < SplitSpectre_get_with() ) {
 		Begin --;
 		Value ++;
 	}
-
 	if (Value < 0.0) {
 		Value = 0.0;
 	}
@@ -225,28 +223,48 @@ void SplitSpectre_scroll_droite_play (void)
 // 
 void split_redraw_image (void)
 {
+	/**
+	GtkAllocation	allocation;
+	
 	if (NULL == VarSplit.AdrWidgetSpectre) return;
-	// PRINT_FUNC_LF();
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
 	gtk_widget_queue_draw_area (
 				VarSplit.AdrWidgetSpectre,
-				VarSplit.AdrWidgetSpectre->allocation.x,
-				VarSplit.AdrWidgetSpectre->allocation.y,
-				VarSplit.AdrWidgetSpectre->allocation.width,
-				VarSplit.AdrWidgetSpectre->allocation.height
+				allocation.x,
+				allocation.y,
+				allocation.width,
+				allocation.height
 				);
+	*/
+	if (NULL == VarSplit.AdrWidgetSpectre) return;
+	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 }
 // 
 // 
-static void split_drag_data_received_file (GtkWidget	   *widget,
-					GdkDragContext     *drag_context,
-					gint                x,
-					gint                y,
-					GtkSelectionData   *data,
-					guint               info,
-					guint               time)
+static void split_drag_data_received_file(
+					GtkWidget        *widget,
+					GdkDragContext   *context,
+					gint              x,
+					gint              y,
+					GtkSelectionData *data,
+					guint             info,
+					guint             time,
+					gpointer          user_data)
 {
-	if (gtk_drag_get_source_widget(drag_context) != widget) {
-		dragndrop_list_drag_data (widget, (gchar *)data->data);
+	/**
+	if( TRUE == VarSplit.BoolPlay ) {
+		wind_info_init (
+			WindMain,
+			_("Veuillez arreter la lecture du fichier"),
+			  "\n",
+			_("avant d'impôrter un fichier."),
+			  "");
+		return;
+	}
+	*/
+	if (gtk_drag_get_source_widget(context) != widget) {
+		// dragndrop_list_drag_data (widget, (gchar *)data->data);
+		dragndrop_list_drag_data( widget, (gchar*)gtk_selection_data_get_data( data ));
 	}
 }
 // 
@@ -276,14 +294,14 @@ void split_set_name_file (void)
 		g_free (Str);	Str = NULL;
 		
 		if (VarSplit.NbrSelecteurs > 1) {
-			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_SIMPLE_, _("Menu: Click droit  /  Ajout plage: Click bouton centre  /  Zoom: Ctrl+Scroll") );
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_SIMPLE_, _("Menu: right click / Adding track: Click the center button  /  Zoom: Ctrl+Scroll") );
 		}
 		else {
-			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_SIMPLE_, _("Ajout plage: Click bouton centre  /  Zoom: Ctrl+Scroll") );
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_SIMPLE_, _("Adding track: Click the center button  /  Zoom: Ctrl+Scroll") );
 		}
 	}
 	else {
-		StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_SIMPLE_, _("<i>Pret pour l'import d'un fichier CUE, WAV, FLAC, OGG, MP3, APE, WMA</i>") );
+		StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_SIMPLE_, _("<i>Ready for imports and a CUE file, WAV, FLAC, OGG, MP3, APE, WMA</i>") );
 	}
 }
 //
@@ -292,6 +310,8 @@ static void VarSplit_thread (void *arg)
 {
 	VarSplit.BoolInThread = TRUE;
 	
+	SplitSpectre_remove();
+	VarSplit.Tags = (INFO_WAV *)tagswav_get_info (VarSplit.PathNameFile);
 	SplitSpectre_read_file_spectre (VarSplit.PathNameFile);
 	
 	VarSplit.BoolInThread = FALSE;
@@ -305,10 +325,10 @@ static gint VarSplit_timeout (gpointer data)
 	if (FALSE == VarSplit.BoolInThread) {
 		gint	IndicePoints = 0;
 				
-		gtk_timeout_remove (VarSplit.HandlerTimeoutDo);
+		g_source_remove (VarSplit.HandlerTimeoutDo);
 		
-		VarSplit.Tags = tagswav_remove_info (VarSplit.Tags);
-		VarSplit.Tags = (INFO_WAV *)tagswav_get_info (VarSplit.PathNameFile);
+		// VarSplit.Tags = tagswav_remove_info (VarSplit.Tags);
+		// VarSplit.Tags = (INFO_WAV *)tagswav_get_info (VarSplit.PathNameFile);
 		
 		// 
 		split_set_name_file ();
@@ -345,25 +365,27 @@ static gint VarSplit_timeout (gpointer data)
 // 
 // IMPORT D'UN FICHIER
 // 
-void split_file_load (gchar *p_PathNameFile)
+void split_file_load( gchar *p_PathNameFile )
 {
 	gchar		*PathNameFile = NULL;
 	TYPE_FILE_IS	TypeFileIs = GetInfo_file_is (p_PathNameFile);
 
+printf("\n---------------------------- split_file_load( %s\n", p_PathNameFile );
+
 	if (0 == strcmp (p_PathNameFile, SPLIT_FILE_TMP_WAV)) {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("Ce fichier appartient a XCFA"),
-			_("Selectionnez un autre fichier."),
+			_("This file belongs XCFA"),
+			_("Select another file."),
 			  "");
 		return;
 	}
 	
 	if (libutils_get_size_file (p_PathNameFile) <= 0) {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("Fichier vide"),
-			_("Le fichier ne contient aucune donnee !!!"),
+			_("Empty file"),
+			_("The file contains no data !!!"),
 			  "");
 		return;
 	}
@@ -380,10 +402,10 @@ void split_file_load (gchar *p_PathNameFile)
 			return;
 		}
 		if (0 == strcmp (PathNameFile, SPLIT_FILE_TMP_WAV)) {
-			wininfo_create (
+			wind_info_init (
 				WindMain,
-				_("Ce fichier appartient a XCFA"),
-				_("Selectionnez un autre fichier."),
+				_("This file belongs XCFA"),
+				_("Select another file."),
 				  "");
 			g_free (PathNameFile);
 			PathNameFile = NULL;
@@ -406,14 +428,14 @@ void split_file_load (gchar *p_PathNameFile)
 		
 		if (FALSE == PrgInit.bool_sox || FALSE == PrgInit.bool_mplayer) {
 		
-			wininfo_create (
+			wind_info_init (
 				WindMain,
-				_("Sox et Mplayer absents"),
-				_("Sox et Mplayer sont absents de votre"),
+				_("Sox and Mplayer not found"),
+				_("Sox et Mplayer are not found"),
 			  	"\n",
-				_("configuration."),
+				_("in your configuration."),
 			  	"\n\n",
-				_("Veuillez les installer pour pouvoir continuer."),
+				_("Please install it and resume"),
 
 				"");
 			return;
@@ -428,12 +450,14 @@ void split_file_load (gchar *p_PathNameFile)
 	
 	SplitConv_to (PathNameFile);
 }
-void split_file_load_continue (gchar *p_PathNameFile)
+void split_file_load_continue( gchar *p_PathNameFile )
 {
 	pthread_t	nmr_tid;
 	gchar		*PathNameFile = p_PathNameFile;
 	TYPE_FILE_IS	TypeFileIs = libutils_test_file_exist (p_PathNameFile);
 	
+printf("---------------------------- BEGIN split_file_load_continue( %s\n", p_PathNameFile );
+
 	if (TRUE == libutils_test_file_exist (PathNameFile) &&
 	    (FILE_IS_WAV == TypeFileIs || FILE_IS_FLAC == TypeFileIs || FILE_IS_MP3 == TypeFileIs || FILE_IS_OGG == TypeFileIs || FILE_IS_APE == TypeFileIs)) {
 		
@@ -458,17 +482,18 @@ void split_file_load_continue (gchar *p_PathNameFile)
 		VarSplit.BoolInThread = TRUE;
 		PRINT("DEBUT TIMEOUT SPLIT");
 		PRINT("DEBUT THREAD SPLIT");
-		VarSplit.HandlerTimeoutDo = gtk_timeout_add (100, VarSplit_timeout, 0);
+		VarSplit.HandlerTimeoutDo = g_timeout_add (100, VarSplit_timeout, 0);
 		pthread_create (&nmr_tid, NULL ,(void *)VarSplit_thread, (void *)NULL);
 	}
 	else {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("Erreur de choix de fichier"),
-			_("Veuillez selectionner un fichier de type WAV FLAC MP3 OGG APE"),
+			_("Error file select"),
+			_("Please select a file type of MP3 WAV OGG FLAC APE"),
 			  "");
 	}
 	split_set_flag_buttons ();
+printf("---------------------------- END   split_file_load_continue( %s\n", p_PathNameFile );
 }
 
 	
@@ -495,15 +520,15 @@ void split_maj_file_load (gchar *path)
 	    FILE_IS_APE == TypeFileIs ||
 	    FILE_IS_WMA == TypeFileIs ||
 	    TRUE == FileIs_g_str_has_suffix (path, ".CUE")) {
-		split_file_load (path);
+		split_file_load( path );
 		BoolTypeFileIsOk = TRUE;
 	}
 	
 	if (FALSE == BoolTypeFileIsOk) {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("Mauvais type de fichier"),
-			_("Les types de fichiers acceptes\nsont: WAV FLAC MP3 OGG APE WMA CUE"),
+			_("Wrong type of file"),
+			_("File types accepted\nsare: WAV FLAC MP3 OGG APE WMA CUE"),
 			  "");
 	}
 }
@@ -511,7 +536,7 @@ void split_maj_file_load (gchar *path)
 // 
 void on_button_importer_split_clicked (GtkButton *button, gpointer user_data)
 {
-	if (GDK_space != keys.keyval)
+	if (GDK_KEY_space != keys.keyval)
 		fileselect_create (_PATH_LOAD_SPLIT_FILE_, Config.PathLoadSplit, split_maj_file_load);
 }
 // INIT WIDGET DE LA DESTINAION DES DECOUPES
@@ -537,7 +562,7 @@ void split_maj_destination (gchar *path)
 // 
 void on_button_destination_split_clicked (GtkButton *button, gpointer user_data)
 {
-	if (GDK_space != keys.keyval) {
+	if (GDK_KEY_space != keys.keyval) {
 		fileselect_create (_PATH_CHOICE_DESTINATION_, Config.PathDestinationSplit, split_maj_destination);
 		split_set_flag_buttons ();
 	}
@@ -551,8 +576,6 @@ void split_load_from_dnd (GSList *p_list)
 	TYPE_FILE_IS	TypeFileIs = FILE_IS_NONE;
 	gboolean	BoolTypeFileIsOk = FALSE;
 	
-	// PRINT_FUNC_LF();
-	
 	while (NULL != gs_List) {
 		if (NULL != (Ptr = (gchar *)gs_List->data)) {
 			if( TRUE == OptionsCommandLine.BoolVerboseMode )
@@ -565,7 +588,7 @@ void split_load_from_dnd (GSList *p_list)
 			    FILE_IS_APE == TypeFileIs ||
 	 		    FILE_IS_WMA == TypeFileIs ||
 			    TRUE == FileIs_g_str_has_suffix (Ptr, ".CUE")) {
-				split_file_load (Ptr);
+				split_file_load( Ptr );
 				BoolTypeFileIsOk = TRUE;
 				break;
 			}
@@ -574,10 +597,10 @@ void split_load_from_dnd (GSList *p_list)
 	}
 	
 	if (FALSE == BoolTypeFileIsOk) {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("Mauvais type de fichier"),
-			_("Les types de fichiers acceptes\nsont: WAV FLAC MP3 OGG APE WMA CUE"),
+			_("Wrong type of file"),
+			_("File types accepted\nsare: WAV FLAC MP3 OGG APE WMA CUE"),
 			  "");
 	}
 	
@@ -588,24 +611,27 @@ void split_load_from_dnd (GSList *p_list)
 // 
 void split_set_value (gdouble p_value)
 {
+	GtkAllocation	allocation;
+	gdouble			Value;
+	
+	Value = gtk_adjustment_get_value( VarSplit.AdjScroll );
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
+	
 	VarSplit.PercentActivePlay = p_value;
 	if (VarSplit.PercentActivePlay >= 100.0) VarSplit.PercentActivePlay = 99.99;
 
-	if( SplitSelector_get_pos_play () > VARSPLIT_SPECTRE_WITH + (gint)VarSplit.AdjScroll->value &&
-	    (gint)VarSplit.AdjScroll->value < SplitSpectre_get_with() ) {
+	if( SplitSelector_get_pos_play () > VARSPLIT_SPECTRE_WITH + (gint)Value &&
+	    (gint)Value < SplitSpectre_get_with() ) {
 		SplitSpectre_scroll_droite_play ();
 	}
 	split_set_time ();
 	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
-	SplitSpectre_draw_lines_play();
-	// gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
+	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 }
 // 
 // 
 void split_end_play (void)
 {
-	PRINT_FUNC_LF();
-	
 	split_set_stop ();
 	
 	gtk_widget_show (GTK_WIDGET (GLADE_GET_OBJECT("button_play_split")));
@@ -634,8 +660,6 @@ gboolean split_is_stop (void)
 // 
 void on_button_play_split_clicked (GtkButton *button, gpointer user_data)
 {
-	// PRINT_FUNC_LF();
-	
 	VarSplit.BoolPlay = TRUE;
 	
 	gtk_widget_show (GTK_WIDGET (GLADE_GET_OBJECT("button_pause_split")));
@@ -659,8 +683,6 @@ void on_button_play_split_clicked (GtkButton *button, gpointer user_data)
 // 
 void on_button_pause_split_clicked (GtkButton *button, gpointer user_data)
 {
-	// PRINT_FUNC_LF();
-	
 	VarSplit.BoolPlay = FALSE;
 	
 	AlsaPlay_stop ();
@@ -685,15 +707,10 @@ void split_play (void)
 // 
 void on_button_play_begin_split_clicked (GtkButton *button, gpointer user_data)
 {
-	// gdouble		Percent;
-	
-	// PRINT_FUNC_LF();
-	
 	gdouble	PercentBegin = SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
 	gdouble	PercentEnd   = SplitSelector_get_percent_begin (VarSplit.SelecteurActif) + SplitSelector_get_percent_for_x_secondes (5);
 	
 	VarSplit.BoolPlay = TRUE;
-	// Percent = SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
 	SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
 	AlsaPlay_song (
 		VarSplit.PathNameFile,
@@ -702,8 +719,6 @@ void on_button_play_begin_split_clicked (GtkButton *button, gpointer user_data)
 		split_set_value,
 		split_end_play
 		);
-	
-	// gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame_choice_reader")),		FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_play_begin_split")),	FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_play_split")),		FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_play_end_split")),	FALSE);
@@ -716,15 +731,10 @@ void on_button_play_begin_split_clicked (GtkButton *button, gpointer user_data)
 // 
 void on_button_play_end_split_clicked (GtkButton *button, gpointer user_data)
 {
-	// gdouble		Percent;
-	
-	// PRINT_FUNC_LF();
-	
 	gdouble	PercentBegin = SplitSelector_get_percent_end (VarSplit.SelecteurActif) - SplitSelector_get_percent_for_x_secondes (5);
 	gdouble	PercentEnd   = SplitSelector_get_percent_end (VarSplit.SelecteurActif);
 	
 	VarSplit.BoolPlay = TRUE;
-	// Percent = SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
 	SplitSelector_get_percent_begin (VarSplit.SelecteurActif);
 	AlsaPlay_song (
 		VarSplit.PathNameFile,
@@ -733,7 +743,6 @@ void on_button_play_end_split_clicked (GtkButton *button, gpointer user_data)
 		split_set_value,
 		split_end_play
 		);
-	
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_play_begin_split")),	FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_play_split")),		FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_play_end_split")),	FALSE);
@@ -776,45 +785,58 @@ void split_from_popup (gint p_choice)
 // 
 void SetAjust (void)
 {
-	// PRINT_FUNC_LF();
-	VarSplit.AdjScroll->value          = Adjust.value;
-	VarSplit.AdjScroll->lower          = Adjust.lower;
-	VarSplit.AdjScroll->upper          = Adjust.upper;
-	VarSplit.AdjScroll->step_increment = Adjust.step_increment;
-	VarSplit.AdjScroll->page_increment = Adjust.page_increment;
-	VarSplit.AdjScroll->page_size      = Adjust.page_size;
+	if( NULL == VarSplit.AdjScroll ) return;
+	gtk_adjustment_set_value( VarSplit.AdjScroll, Adjust.value );
+	gtk_adjustment_set_lower( VarSplit.AdjScroll, Adjust.lower );
+	gtk_adjustment_set_upper( VarSplit.AdjScroll, Adjust.upper );
+	gtk_adjustment_set_step_increment( VarSplit.AdjScroll, Adjust.step_increment );
+	gtk_adjustment_set_page_increment( VarSplit.AdjScroll, Adjust.page_increment );
+	gtk_adjustment_set_page_size( VarSplit.AdjScroll, Adjust.page_size );
+	
 	gtk_adjustment_value_changed( VarSplit.AdjScroll );
 }
 // 
 // 
 void page_plus_scrolled ( gint p_CursorX )
 {
-	// PRINT_FUNC_LF();
+	gdouble			Value;
+	GtkAllocation	allocation;
+
+	Value = gtk_adjustment_get_value( VarSplit.AdjScroll );
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
+
 	Adjust.mul           += 1;
 	Adjust.with           = SplitSpectre_get_with();
 	Adjust.lower          = 0.;
 	Adjust.upper          = Adjust.with;
 	Adjust.step_increment = 10;
-	Adjust.page_size      = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.page_increment = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.value          = VarSplit.AdjScroll->value + p_CursorX;
-	SetAjust ();
+	Adjust.page_size      = allocation.width;
+	Adjust.page_increment = allocation.width;
+	Adjust.value          = Value + (gdouble)p_CursorX;
+
+	SetAjust();
+	SetAjust();
 }
 // 
 // 
 void rigtht_plus_scrolled (void)
 {
-	// PRINT_FUNC_LF();
+	gdouble			Value;
+	GtkAllocation	allocation;
+
+	Value = gtk_adjustment_get_value( VarSplit.AdjScroll );
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
+
 	// Adjust.mul           += 1;
 	Adjust.with           = SplitSpectre_get_with();
 	Adjust.lower          = 0.;
 	Adjust.upper          = Adjust.with;
 	Adjust.step_increment = 10;
-	Adjust.page_size      = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.page_increment = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.value          = VarSplit.AdjScroll->value;
+	Adjust.page_size      = allocation.width;
+	Adjust.page_increment = allocation.width;
+	Adjust.value          = Value;
 	Adjust.value         += 10;
-	while( Adjust.value > Adjust.with - VarSplit.AdrWidgetSpectre->allocation.width )
+	while( Adjust.value > Adjust.with - allocation.width )
 		Adjust.value --;
 	SetAjust ();
 }
@@ -822,39 +844,50 @@ void rigtht_plus_scrolled (void)
 // 
 void page_moins_scrolled ( gint p_CursorX )
 {
-	// PRINT_FUNC_LF();
+	gdouble			Value;
+
+	Value = gtk_adjustment_get_value( VarSplit.AdjScroll );
+	GtkAllocation	allocation;
+
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
+
 	Adjust.mul           -= 1;
 	if( Adjust.mul < 1 ) Adjust.mul = 1;
 	Adjust.with           = SplitSpectre_get_with();
-	if( Adjust.with < VarSplit.AdrWidgetSpectre->allocation.width ) {
-		Adjust.with   = VarSplit.AdrWidgetSpectre->allocation.width;
+	if( Adjust.with < allocation.width ) {
+		Adjust.with   = allocation.width;
 		Adjust.value  = 0;
 	} else {
-		Adjust.value          = VarSplit.AdjScroll->value - p_CursorX;
+		Adjust.value          = Value - p_CursorX;
 	}
-	while( Adjust.value > Adjust.with - VarSplit.AdrWidgetSpectre->allocation.width )
+	while( Adjust.value > Adjust.with - allocation.width )
 		Adjust.value --;
 	if( Adjust.value < 0. ) Adjust.value = 0.;
 	Adjust.lower          = 0.;
 	Adjust.upper          = Adjust.with;
 	Adjust.step_increment = 10;
-	Adjust.page_size      = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.page_increment = VarSplit.AdrWidgetSpectre->allocation.width;
+	Adjust.page_size      = allocation.width;
+	Adjust.page_increment = allocation.width;
 	SetAjust ();
 }
 // 
 // 
 void left_plus_scrolled (void)
 {
-	// PRINT_FUNC_LF();
+	gdouble			Value;
+	GtkAllocation	allocation;
+
+	Value = gtk_adjustment_get_value( VarSplit.AdjScroll );
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
+
 	// Adjust.mul           += 1;
 	Adjust.with           = SplitSpectre_get_with();
 	Adjust.lower          = 0.;
 	Adjust.upper          = Adjust.with;
 	Adjust.step_increment = 10;
-	Adjust.page_size      = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.page_increment = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.value          = VarSplit.AdjScroll->value;
+	Adjust.page_size      = allocation.width;
+	Adjust.page_increment = allocation.width;
+	Adjust.value          = Value;
 	Adjust.value         -= 10;
 	while( Adjust.value < 0.0 )
 		Adjust.value = 0.0;
@@ -869,10 +902,10 @@ void on_image_splitspectre_chrono_realize (GtkWidget *widget, gpointer user_data
 }
 // 
 // 
-gboolean on_eventbox_splitspectre_chrono_expose_event (GtkWidget *drawing, GdkEventExpose *e, gpointer data)
+gboolean on_eventbox_splitspectre_chrono_draw(  GtkWidget *widget, cairo_t *p_cr, gpointer user_data )
 {
-	SplitSpectre_draw_chrono( VarSplit.AdrWidgetSpectreChrono );
-	return TRUE;
+	SplitSpectre_draw_chrono( VarSplit.AdrWidgetSpectreChrono, p_cr );
+	return FALSE;
 }
 // 
 // 
@@ -880,9 +913,14 @@ gboolean on_eventbox_splitspectre_chrono_event (GtkWidget *widget, GdkEvent *eve
 {
 	gint			CursorX, CursorY;
 	GdkModifierType		state;
-		
-	// GET EMPLACEMENT CURSOR MOUSE
- 	gdk_window_get_pointer (((GdkEventButton*)event)->window, &CursorX, &CursorY, &state);	
+	GtkAllocation	allocation;
+	
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );	
+	/* Si pas de selection a cet endroit retour */
+	GdkDeviceManager *manager = gdk_display_get_device_manager( gdk_display_get_default() );
+	GdkDevice		 *device = gdk_device_manager_get_client_pointer( manager );
+	gdk_window_get_device_position( ((GdkEventButton*)event)->window, device, &CursorX, &CursorY, &state );
+ 	// gdk_window_get_pointer (((GdkEventButton*)event)->window, &CursorX, &CursorY, &state);	
 	
 	// SI LE CURSEUR N EST PAS DANS LA ZONE ALORS SORTIE
 	if (CursorX < VARSPLIT_CHRONO_X) return FALSE;
@@ -903,7 +941,6 @@ void on_image_splitspectre_top_realize (GtkWidget *widget, gpointer user_data)
 // 
 gboolean on_eventbox_splitspectre_top_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
-	// static gint Nbr = 0;
 	gboolean		BoolEventTypeScroll = (GDK_SCROLL == event->type) ? TRUE : FALSE;
 	gint			EventTypeScrollDirection = ((GdkEventScroll*)event)->direction;
 	gint			CursorX, CursorY;
@@ -911,16 +948,22 @@ gboolean on_eventbox_splitspectre_top_event (GtkWidget *widget, GdkEvent *event,
 	// gboolean		bool_click_droit = (((GdkEventButton*)event)->button == 3);
 	// gboolean		bool_click_centre = (((GdkEventButton*)event)->button == 2);
 	gboolean		bool_click_gauche = (((GdkEventButton*)event)->button == 1);
-	
-	// PRINT("");
- 	
- 	// GET EMPLACEMENT CURSOR MOUSE
- 	gdk_window_get_pointer (((GdkEventButton*)event)->window, &CursorX, &CursorY, &state);	
+	gdouble			Value;
+	Value = gtk_adjustment_get_value( VarSplit.AdjScroll );
+	GtkAllocation	allocation;
+
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
+
+	/* Si pas de selection a cet endroit retour */
+	GdkDeviceManager *manager = gdk_display_get_device_manager( gdk_display_get_default() );
+	GdkDevice		 *device = gdk_device_manager_get_client_pointer( manager );
+	gdk_window_get_device_position( ((GdkEventButton*)event)->window, device, &CursorX, &CursorY, &state );
+ 	// gdk_window_get_pointer (((GdkEventButton*)event)->window, &CursorX, &CursorY, &state);	
 	
 	// UN CLICK BOUTON SOURIS : PRESSED
 	if (TRUE == bool_click_gauche && event->type == GDK_BUTTON_PRESS) {
 		gint Pos;
-		CursorX += (gint)VarSplit.AdjScroll->value;
+		CursorX += (gint)Value;
 		for (Pos = 0; Pos < VarSplit.NbrSelecteurs ; Pos ++) {
 			if (CursorX > SplitSelector_get_pos_begin (Pos) && CursorX < SplitSelector_get_pos_end (Pos)) {
 				VarSplit.SelecteurActif = Pos;
@@ -955,7 +998,6 @@ gboolean on_eventbox_splitspectre_top_event (GtkWidget *widget, GdkEvent *event,
 			if( LenPos < LenWin ) {
 				demi = ( LenWin - LenPos ) / 2;
 				Adjust.value = BeginPos - demi;
-				
 			}
 			// LA SELECTION EST PLUS GRANDE QUE LA FENETRE
 			else if( LenPos > LenWin ) {
@@ -969,7 +1011,6 @@ gboolean on_eventbox_splitspectre_top_event (GtkWidget *widget, GdkEvent *event,
 			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
 		}
-		
 	}
 	else {
 		gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreChrono );
@@ -979,20 +1020,40 @@ gboolean on_eventbox_splitspectre_top_event (GtkWidget *widget, GdkEvent *event,
 }
 // 
 // 
-gboolean on_eventbox_splitspectre_top_expose_event (GtkWidget *drawing, GdkEventExpose *e, gpointer data)
+gboolean on_eventbox_splitspectre_top_draw( GtkWidget *widget, cairo_t *p_cr, gpointer user_data )
 {
-	SplitSpectre_draw_top( VarSplit.AdrWidgetSpectreTop );
-	return TRUE;
+	SplitSpectre_draw_top( VarSplit.AdrWidgetSpectreTop, p_cr );
+	return FALSE;
 }
+
+void split_realize( void )
+{
+	if( NULL != VarSplit.RangeAdjScroll && NULL != VarSplit.AdrWidgetSpectre ) {
+
+		GtkAllocation	allocation;
+		gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
+		
+		VarSplit.AdjScroll    = gtk_range_get_adjustment( GTK_RANGE(VarSplit.RangeAdjScroll) );
+		Adjust.value          = gtk_adjustment_get_value( VarSplit.AdjScroll );
+		Adjust.lower          = gtk_adjustment_get_lower( VarSplit.AdjScroll );
+		Adjust.upper          = gtk_adjustment_get_upper( VarSplit.AdjScroll );
+		Adjust.step_increment = gtk_adjustment_get_step_increment( VarSplit.AdjScroll );
+		Adjust.page_size      = gtk_adjustment_get_page_size( VarSplit.AdjScroll );
+		Adjust.page_increment = gtk_adjustment_get_page_increment( VarSplit.AdjScroll );
+		Adjust.with           = allocation.width;
+		Adjust.mul            = 1;
+	}
+}
+
 // IMAGE
 // 
 void on_image_split_spectre_realize (GtkWidget *widget, gpointer user_data)
 {
-	GtkScrolledWindow	*AdrScrolledWindow;
-	
+	GtkAllocation	allocation;
+
 	// INIT COORDONNEES WIDGET
 	VarSplit.AdrWidgetSpectre = widget;
-	
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
 	// 
 	gtk_widget_grab_focus (VarSplit.AdrWidgetSpectre);
 	
@@ -1023,44 +1084,35 @@ void on_image_split_spectre_realize (GtkWidget *widget, gpointer user_data)
 	VarSplit.TypeCursorSpectre           = _CURSOR_IS_NONE_;
 	VarSplit.BoolPlay                    = FALSE;
 	VarSplit.PercentActivePlay           = 0.0;
-	VarSplit.BoolQueueDrawSpectre        = FALSE;
-	VarSplit.BoolQueueDrawChrono         = FALSE;
-	VarSplit.BoolQueueDrawTop            = FALSE;
 	VarSplit.BoolBlankWithCue            = FALSE;
-	
-	// INIT SCROLL
-	AdrScrolledWindow     = GTK_SCROLLED_WINDOW (GLADE_GET_OBJECT("scrolledwindow_splitspectre"));
-	VarSplit.AdjScroll    = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (AdrScrolledWindow));
-	Adjust.mul            = 1;
-	Adjust.with           = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.lower          = VarSplit.AdjScroll->lower = 0.0;
-	Adjust.upper          = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.step_increment = VarSplit.AdjScroll->step_increment = 10.0;
-	Adjust.page_size      = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.page_increment = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.value          = VarSplit.AdjScroll->value = 0.0;
+		
+	split_realize();
 	SetAjust ();
-	
+
 	gtk_widget_show (GTK_WIDGET (GLADE_GET_OBJECT("button_play_split")));
 	gtk_widget_hide (GTK_WIDGET (GLADE_GET_OBJECT("button_pause_split")));
 	
 	split_set_flag_buttons ();
 	split_set_time ();
 }
+
+
 // 
 // 
 gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 	gboolean		BoolEventTypeScroll = (GDK_SCROLL == event->type) ? TRUE : FALSE;
-	gint			EventTypeScrollDirection = ((GdkEventScroll*)event)->direction;
+	// gint			EventTypeScrollDirection = ((GdkEventScroll*)event)->direction;
 	gint			CursorX, _CursorX, CursorY;
 	GdkModifierType		state;
 	gboolean		bool_click_droit = (((GdkEventButton*)event)->button == 3);
 	gboolean		bool_click_centre = (((GdkEventButton*)event)->button == 2);
 	gboolean		bool_click_gauche = (((GdkEventButton*)event)->button == 1);
-	
+	gdouble			Value;
+	gdouble 		direction_x, direction_y;
+	GtkAllocation	allocation;
+
 	// PRINT_FUNC_LF();
-	
 	// IMPOSER UN REAFFICHAGE COMPLET
 	// g_print( "event->type = %d\n", event->type );
 	if( 29 == event->type ) {
@@ -1073,21 +1125,27 @@ gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpo
 		return FALSE;
 	}
 	
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
+	
+	Adjust.value          = 
+	Value                 = gtk_adjustment_get_value( VarSplit.AdjScroll );
 	Adjust.with           = SplitSpectre_get_with();
-	Adjust.lower          = VarSplit.AdjScroll->lower;
+	Adjust.lower          = gtk_adjustment_get_lower( VarSplit.AdjScroll );
 	Adjust.upper          = Adjust.with;
-	Adjust.step_increment = VarSplit.AdjScroll->step_increment;
-	Adjust.page_size      = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.page_increment = VarSplit.AdrWidgetSpectre->allocation.width;
-	Adjust.value          = VarSplit.AdjScroll->value;
+	Adjust.step_increment = gtk_adjustment_get_step_increment( VarSplit.AdjScroll );
+	Adjust.page_size      = allocation.width;
+	Adjust.page_increment = allocation.width;
 	while( Adjust.value + Adjust.page_size > Adjust.upper )
-		Adjust.value --;
+		Adjust.value --; 
 	SetAjust ();
  	
- 	// GET EMPLACEMENT CURSOR MOUSE
- 	gdk_window_get_pointer (((GdkEventButton*)event)->window, &CursorX, &CursorY, &state);	
-	_CursorX = CursorX + (gint)VarSplit.AdjScroll->value;
-	
+	// Si pas de selection a cet endroit retour
+	GdkDeviceManager *manager = gdk_display_get_device_manager( gdk_display_get_default() );
+	GdkDevice		 *device = gdk_device_manager_get_client_pointer( manager );
+	gdk_window_get_device_position( ((GdkEventButton*)event)->window, device, &CursorX, &CursorY, &state );
+ 	// gdk_window_get_pointer (((GdkEventButton*)event)->window, &CursorX, &CursorY, &state);	
+	_CursorX = CursorX + (gint)gtk_adjustment_get_value( VarSplit.AdjScroll );
+
 	// CHERCHE SI SELECTION
 	if (FALSE == VarSplit.BoolEventButtonPressSpectre) {
 		if (VarSplit.NbrSelecteurs > 0) {
@@ -1121,27 +1179,33 @@ gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpo
 			VarSplit.TypeCursorSpectre = _CURSOR_IS_NONE_;
 		}
 	}
+
+	gdk_event_get_scroll_deltas( (const GdkEvent *)event, &direction_x, &direction_y );
 	
 	// SCROLL
 	if( TRUE == BoolEventTypeScroll && VarSplit.NbrSelecteurs > 0 ) {
 		if( TRUE == keys.BoolGDK_Control_L_R ) {
-			if (GDK_SCROLL_UP == EventTypeScrollDirection) {
+			if( direction_y == -1. ) {
 				page_plus_scrolled( CursorX );
 				gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 				gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
 			}
-			else if (GDK_SCROLL_DOWN == EventTypeScrollDirection) {
+			else if( direction_y == 1. ) {
 				page_moins_scrolled( CursorX );
 				gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 				gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
 			}
 		}
 		else {
-			if (GDK_SCROLL_UP == EventTypeScrollDirection) {
+			if( direction_y == -1. ) {
 				rigtht_plus_scrolled ();
+				gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
+				gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
 			}
-			else if (GDK_SCROLL_DOWN == EventTypeScrollDirection) {
+			else if( direction_y == 1. ) {
 				left_plus_scrolled ();
+				gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
+				gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
 			}
 		}
 	}
@@ -1216,17 +1280,17 @@ gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpo
 	// MOVE CURSEUR
 	if (TRUE == VarSplit.BoolEventButtonPressSpectre && TRUE == bool_click_gauche) {
 	
-		gint	end      = VARSPLIT_SPECTRE_WITH + (gint)VarSplit.AdjScroll->value;
+		gint	end      = VARSPLIT_SPECTRE_WITH + (gint)Value;
 	
 		// SCROLL RIGHT
-		if( (gint)VarSplit.AdjScroll->value >= 0 && _CursorX >= end ) {
+		if( (gint)Value >= 0 && _CursorX >= end ) {
 			rigtht_plus_scrolled ();
 			rigtht_plus_scrolled ();
 			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
 		}
 		// SCROLL LEFT
-		else if( (gint)VarSplit.AdjScroll->value > 0 && _CursorX < (gint)VarSplit.AdjScroll->value ) {
+		else if( (gint)Value > 0 && _CursorX < (gint)Value ) {
 			left_plus_scrolled ();
 			left_plus_scrolled ();
 			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
@@ -1254,37 +1318,38 @@ gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpo
 	split_set_flag_buttons ();
 	
 	if( 4 == event->type || 7 == event->type  || 29 == event->type ) {
-		// gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
+		gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 	}
 	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreChrono );
+	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
+
+	return FALSE;
+}
+// 
+// 
+gboolean on_eventbox_splitspectre_draw( GtkWidget *widget, cairo_t *p_cr, gpointer user_data )
+{
+	SplitSpectre_draw_lines( VarSplit.AdrWidgetSpectre, p_cr );
+	return FALSE;
+}
+// 
+// 
+void on_scrollbar_split_realize( GtkWidget *widget, gpointer user_data )
+{
+	VarSplit.RangeAdjScroll = GTK_RANGE(widget);
+	split_realize();
+}
+// SCROLLEDWINDOW
+// 
+gboolean on_scrollbar_split_event( GtkWidget *widget, GdkEvent *event, gpointer user_data )
+{
+	Adjust.value          = gtk_adjustment_get_value( VarSplit.AdjScroll );
+	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
+	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
+	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreChrono );
 
 	return FALSE;
 }
-// 
-// 
-gboolean on_eventbox_splitspectre_expose_event (GtkWidget *drawing, GdkEventExpose *e, gpointer data)
-{
-	SplitSpectre_draw_lines();
-	return TRUE;
-}
-// SCROLLEDWINDOW
-// 
-gboolean on_scrolledwindow_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
-{
-	// PRINT_FUNC_LF();
-	Adjust.value          = VarSplit.AdjScroll->value;
-	if (GDK_EXPOSE == event->type) {		
-		gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
-		gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
-		gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreChrono );
-	}
-
-	return FALSE;
-}
-
-
-
-
 
 
 
