@@ -1,9 +1,9 @@
  /*
  *  file      : split_selector.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -133,7 +133,7 @@ void SplitSelector_cut (void)
 	else if (VarSplit.NbrSelecteurs > 1) {
 		
 		if (TRUE == AlsaPlay_is_play ()) {
-			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Suppression pendant la lecture impossible") );
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Deleting not during playback") );
 		}
 		else {
 			gint	Zone = 0;
@@ -210,6 +210,7 @@ void SplitSelector_add (gint p_CursorX)
 	gint			Cpt; 	
 	gdouble			PercentCursorX;
 	gint			Len;
+	GtkAllocation	allocation;
 
 	// PRINT_FUNC_LF();
 		
@@ -217,6 +218,7 @@ void SplitSelector_add (gint p_CursorX)
 	// 
 	// CAS 1 : CursorX < BEGIN_MIN
 	// 
+	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
 	if (CursorX < SplitSelector_get_pos_begin (0)) {
 		
 		PRINT("CAS 1 : CursorX < BEGIN_MIN");
@@ -226,13 +228,13 @@ void SplitSelector_add (gint p_CursorX)
 		PercentCursorX = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 		Len = SplitSelector_get_diff_sec (0.0, PercentCursorX);
 		if (Len < 5) {
-			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Time of less than 5 seconds between marker and cursor !") );
 			return;
 		}
 		
 		Len = SplitSelector_get_diff_sec (PercentCursorX, VarSplit.Selecteur [ 0 ] . PercentBegin);
 		if (Len < 5) {
-			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Time of less than 5 seconds between marker and cursor !") );
 			return;
 		}
 		
@@ -286,13 +288,13 @@ void SplitSelector_add (gint p_CursorX)
 		PercentCursorX = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 		Len = SplitSelector_get_diff_sec (VarSplit.Selecteur [ 0 ] . PercentEnd, PercentCursorX);
 		if (Len < 5) {
-			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Time of less than 5 seconds between marker and cursor !") );
 			return;
 		}
 		
 		Len = SplitSelector_get_diff_sec (PercentCursorX, 100.0);
 		if (Len < 5) {
-			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Time of less than 5 seconds between marker and cursor !") );
 			return;
 		}
 		
@@ -349,14 +351,14 @@ void SplitSelector_add (gint p_CursorX)
 				Len = SplitSelector_get_diff_sec (VarSplit.Selecteur [ Cpt ] . PercentBegin, PercentCursorX);
 				if (Len < 5) {
 				PRINT("1- if (Len < 5) {");
-					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
+					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Time of less than 5 seconds between marker and cursor !") );
 					return;
 				}
 				
 				Len = SplitSelector_get_diff_sec (PercentCursorX, VarSplit.Selecteur [ Cpt ] . PercentEnd);
 				if (Len < 5) {
 				PRINT("2- if (Len < 5) {");
-					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
+					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Time of less than 5 seconds between marker and cursor !") );
 					return;
 				}
 		
@@ -426,13 +428,13 @@ void SplitSelector_add (gint p_CursorX)
 				PercentCursorX = ((gdouble)CursorX / (gdouble)SplitSpectre_get_with() ) * 100.0;
 				Len = SplitSelector_get_diff_sec (VarSplit.Selecteur [ Cpt ] . PercentEnd, PercentCursorX);
 				if (Len < 5) {
-					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
+					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Time of less than 5 seconds between marker and cursor !") );
 					return;
 				}
 				
 				Len = SplitSelector_get_diff_sec (PercentCursorX, VarSplit.Selecteur [ Cpt +1 ] . PercentBegin);
 				if (Len < 5) {
-					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Temps inferieur a 5 secondes entre marqueur et curseur !") );
+					StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Time of less than 5 seconds between marker and cursor !") );
 					return;
 				}
 		
@@ -693,7 +695,9 @@ gboolean SplitSelector_cursor_in_box_play (gint p_cursor_x, gint p_cursor_y)
 	if (VarSplit.PercentActivePlay >= 0.0) {
 		
 		gint	SelPlay = SplitSelector_get_pos_play ();
+		GtkAllocation	allocation;
 		
+		gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
 		if (p_cursor_x > SelPlay -6 && p_cursor_x < SelPlay +7)
 			if (p_cursor_y > VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H -12 && p_cursor_y < VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H)
 				return (TRUE);
@@ -706,8 +710,10 @@ gboolean SplitSelector_cursor_in_line_play (gint p_cursor_x, gint p_cursor_y)
 {
 	if (VarSplit.PercentActivePlay >= 0.0) {
 		
+		GtkAllocation	allocation;
 		gint	SelPlay = SplitSelector_get_pos_play ();
-		
+	
+		gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
 		if (p_cursor_x    == SelPlay ||
 		    p_cursor_x +1 == SelPlay ||
 		    p_cursor_x -1 == SelPlay) {
@@ -719,13 +725,12 @@ gboolean SplitSelector_cursor_in_line_play (gint p_cursor_x, gint p_cursor_y)
 }
 // 
 // 
-void SplitSelector_set_pos_play (gint p_play)
+void SplitSelector_set_pos_play( gint p_play )
 {
-	gint	With       = SplitSpectre_get_with();
+	gint	With = SplitSpectre_get_with();
 	
 	if( p_play < 0 ) p_play = 0;
 	if( p_play > With ) p_play = With;
-	
 	VarSplit.PercentActivePlay = ((gdouble)p_play / (gdouble)With ) * 100.0;
 }
 
