@@ -1,9 +1,9 @@
  /*
  *  file      : web.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -168,24 +168,24 @@ void web_goto_url (gchar *str_web)
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), NOTEBOOK_PRGEXTERNES);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_app_externes")), NOTEBOOK_OPTIONS_EXTRA);
 		
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("PAS de navigateur present"),
-			_("L'acces au web est impossible car aucun navigateur"),
+			_("No web browser"),
+			_("No Web access: no web browser"),
 			  "\n",
-			_("n'est present dans votre configuration."),
+			_("found in your system."),
 			  "\n\n",
-			_("Veuillez installez un navigateur."),
+			_("Please install a web browser."),
 			  "");
 		return;
 	}
 
 	if (CdCurl_test_access_web () == FALSE) {
 		
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("La liaison internet est absente"),
-			_("Vous devez ouvrir l'acces internet"),
+			_("A web connection is missing"),
+			_("You need to enable web access"),
 			  "");
 		return;
 	}
@@ -229,15 +229,14 @@ void web_goto_manpage (gchar *NameManPage)
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), NOTEBOOK_PRGEXTERNES);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_app_externes")), NOTEBOOK_OPTIONS_EXTRA);
 		
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("PAS de navigateur present"),
+			_("No web browser"),
+			_("No Web access: no web browser"),
 			  "\n",
-			_("   L'acces au web est impossible car aucun navigateur"),
-			  "        \n",
-			_("   n'est present dans votre configuration."),
+			_("found in your system."),
 			  "\n\n",
-			_("   Veuillez installez un navigateur."),
+			_("Please install a web browser."),
 			  "\n",
 			  "");
 		return;
@@ -245,10 +244,10 @@ void web_goto_manpage (gchar *NameManPage)
 
 	if (libutils_find_file (NameManPage) == FALSE) {
 		g_print("The application is missing, you must install [ %s ]\n", NameManPage);
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("L'application est absente."),
-			_("Veuillez installer : "), "<b>", NameManPage, "</b>",
+			_("Application is missing."),
+			_("Please install : "), "<b>", NameManPage, "</b>",
 			  "\n",
 			  "");
 		return;
