@@ -1,9 +1,9 @@
  /*
  *  file      : win_scan.h
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -32,7 +32,8 @@ typedef enum {
 	WINDSCAN_PROGRESS
 } TYPE_PROGRESS;
 
-gboolean WindScan_open (gchar *title, TYPE_PROGRESS TypeProgress);
+gboolean wind_scan_init( GtkWidget *FromWindMain, gchar *title, TYPE_PROGRESS TypeProgress );
+// gboolean WindScan_open (gchar *title, TYPE_PROGRESS TypeProgress);
 void	 WindScan_close (void);
 void	 WindScan_set_pulse (void);
 void	 WindScan_set_progress (gchar *p_str, double p_etat);
